.. PyExoCross documentation master file, created by
   sphinx-quickstart on Fri Apr 28 15:25:07 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to PyExoCross's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro.md
   cite.md
   python_api/index
   command.md
   requirements.md
   examples.md
   basicinfo.md
   conversion.md
   partitionfunc.md
   specificheats.md
   coolingfunc.md
   lifetimes.md
   oscillatorstrengths.md
   stickspectra.md
   crosssections.md
   nonlte.md
   filters.md
   report.md
   license.md


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
